OpenDatabaseOptions class abstract

Options for opening the database see openDatabase for details

Constructors

OpenDatabaseOptions({int? version, OnDatabaseConfigureFn? onConfigure, OnDatabaseCreateFn? onCreate, OnDatabaseVersionChangeFn? onUpgrade, OnDatabaseVersionChangeFn? onDowngrade, OnDatabaseOpenFn? onOpen, bool? readOnly = false, bool? singleInstance = true, bool? rollbackActiveTransactionOnOpen})
Open the database at a given path
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
onConfigure OnDatabaseConfigureFn?
called right after opening the database.
no setter
onCreate OnDatabaseCreateFn?
Called when the database is created.
no setter
onDowngrade OnDatabaseVersionChangeFn?
Called when the database is downgraded.
no setter
onOpen OnDatabaseOpenFn?
Called after all other callbacks have been called.
no setter
onUpgrade OnDatabaseVersionChangeFn?
Called when the database is upgraded.
no setter
readOnly bool
Open the database in read-only mode (no callback called).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleInstance bool
The existing single-instance (hot-restart)
no setter
version int?
Specify the expected version.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited